# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class JWTPair(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'scope': 'str',
        'refresh_token': 'str',
        'token': 'str'
    }

    attribute_map = {
        'scope': 'scope',
        'refresh_token': 'refreshToken',
        'token': 'token'
    }

    def __init__(self, scope=None, refresh_token=None, token=None):  # noqa: E501
        """JWTPair - a model defined in Swagger"""  # noqa: E501
        self._scope = None
        self._refresh_token = None
        self._token = None
        self.discriminator = None
        if scope is not None:
            self.scope = scope
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if token is not None:
            self.token = token

    @property
    def scope(self):
        """Gets the scope of this JWTPair.  # noqa: E501


        :return: The scope of this JWTPair.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this JWTPair.


        :param scope: The scope of this JWTPair.  # noqa: E501
        :type: str
        """
        allowed_values = ["CUSTOMER_USER", "PRE_VERIFICATION_TOKEN", "REFRESH_TOKEN", "SYS_ADMIN", "TENANT_ADMIN"]  # noqa: E501
        if scope not in allowed_values:
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def refresh_token(self):
        """Gets the refresh_token of this JWTPair.  # noqa: E501

        The JWT Refresh Token. Used to get new JWT Access Token if old one has expired.  # noqa: E501

        :return: The refresh_token of this JWTPair.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this JWTPair.

        The JWT Refresh Token. Used to get new JWT Access Token if old one has expired.  # noqa: E501

        :param refresh_token: The refresh_token of this JWTPair.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def token(self):
        """Gets the token of this JWTPair.  # noqa: E501

        The JWT Access Token. Used to perform API calls.  # noqa: E501

        :return: The token of this JWTPair.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this JWTPair.

        The JWT Access Token. Used to perform API calls.  # noqa: E501

        :param token: The token of this JWTPair.  # noqa: E501
        :type: str
        """

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JWTPair, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JWTPair):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
