#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from .self_registration_controller_api import SelfRegistrationControllerApi
from .http_integration_controller_api import HttpIntegrationControllerApi
from .asset_controller_api import AssetControllerApi
from .device_group_ota_package_controller_api import DeviceGroupOtaPackageControllerApi
from .edge_controller_api import EdgeControllerApi
from .ocean_connect_integration_controller_api import OceanConnectIntegrationControllerApi
from .user_permissions_controller_api import UserPermissionsControllerApi
from .owner_controller_api import OwnerControllerApi
from .rpc_v_2_controller_api import RpcV2ControllerApi
from .edge_event_controller_api import EdgeEventControllerApi
from .customer_controller_api import CustomerControllerApi
from .user_controller_api import UserControllerApi
from .group_permission_controller_api import GroupPermissionControllerApi
from .device_controller_api import DeviceControllerApi
from .converter_controller_api import ConverterControllerApi
from .entity_view_controller_api import EntityViewControllerApi
from .rule_engine_controller_api import RuleEngineControllerApi
from .admin_controller_api import AdminControllerApi
from .t_mobile_iot_cdp_integration_controller_api import TMobileIotCdpIntegrationControllerApi
from .sign_up_controller_api import SignUpControllerApi
from .trail_controller_api import TrailControllerApi
from .thing_park_integration_controller_api import ThingParkIntegrationControllerApi
from .sig_fox_integration_controller_api import SigFoxIntegrationControllerApi
from .scheduler_event_controller_api import SchedulerEventControllerApi
from .report_controller_api import ReportControllerApi
from .dashboard_controller_api import DashboardControllerApi
from .integration_controller_api import IntegrationControllerApi
from .custom_menu_controller_api import CustomMenuControllerApi
from .lwm_2m_controller_api import Lwm2mControllerApi
from .custom_translation_controller_api import CustomTranslationControllerApi
from .role_controller_api import RoleControllerApi
from .blob_entity_controller_api import BlobEntityControllerApi
from .loriot_integration_controller_api import LoriotIntegrationControllerApi
from .tenant_controller_api import TenantControllerApi
from .chirp_stack_integration_controller_api import ChirpStackIntegrationControllerApi
from .white_labeling_controller_api import WhiteLabelingControllerApi
from .ota_package_controller_api import OtaPackageControllerApi
from .entity_group_controller_api import EntityGroupControllerApi
from .subscription_controller_api import SubscriptionControllerApi
from .solution_controller_api import SolutionControllerApi
from .device_profile_controller_api import DeviceProfileControllerApi
from .asset_profile_controller_api import AssetProfileControllerApi
from .two_factor_auth_controller_api import TwoFactorAuthControllerApi
from .device_connectivity_controller_api import DeviceConnectivityControllerApi
from .mail_config_template_controller_api import MailConfigTemplateControllerApi
