#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from .o_auth_2_config_template_controller_api import OAuth2ConfigTemplateControllerApi
from .asset_controller_api import AssetControllerApi
from .rule_chain_controller_api import RuleChainControllerApi
from .auth_controller_api import AuthControllerApi
from .event_controller_api import EventControllerApi
from .telemetry_controller_api import TelemetryControllerApi
from .alarm_controller_api import AlarmControllerApi
from .edge_controller_api import EdgeControllerApi
from .rpc_v_2_controller_api import RpcV2ControllerApi
from .edge_event_controller_api import EdgeEventControllerApi
from .customer_controller_api import CustomerControllerApi
from .user_controller_api import UserControllerApi
from .queue_controller_api import QueueControllerApi
from .rpc_v_1_controller_api import RpcV1ControllerApi
from .device_controller_api import DeviceControllerApi
from .entity_relation_controller_api import EntityRelationControllerApi
from .entity_view_controller_api import EntityViewControllerApi
from .admin_controller_api import AdminControllerApi
from .tb_resource_controller_api import TbResourceControllerApi
from .o_auth_2_controller_api import OAuth2ControllerApi
from .tenant_profile_controller_api import TenantProfileControllerApi
from .widgets_bundle_controller_api import WidgetsBundleControllerApi
from .device_profile_controller_api import DeviceProfileControllerApi
from .dashboard_controller_api import DashboardControllerApi
from .entity_query_controller_api import EntityQueryControllerApi
from .widget_type_controller_api import WidgetTypeControllerApi
from .audit_log_controller_api import AuditLogControllerApi
from .lwm_2m_controller_api import Lwm2mControllerApi
from .component_descriptor_controller_api import ComponentDescriptorControllerApi
from .tenant_controller_api import TenantControllerApi
from .ota_package_controller_api import OtaPackageControllerApi
from .entities_version_control_controller_api import EntitiesVersionControlControllerApi
from .device_api_controller_api import DeviceApiControllerApi
from .two_factor_auth_controller_api import TwoFactorAuthControllerApi
from .alarm_comment_controller_api import AlarmCommentControllerApi
from .asset_profile_controller_api import AssetProfileControllerApi
from .notification_controller_api import NotificationControllerApi
from .notification_rule_controller_api import NotificationRuleControllerApi
from .notification_target_controller_api import NotificationTargetControllerApi
from .notification_template_controller_api import NotificationTemplateControllerApi
from .usage_info_controller_api import UsageInfoControllerApi
from .two_factor_auth_config_controller_api import TwoFactorAuthConfigControllerApi
from .image_controller_api import ImageControllerApi
